==> POCSdk-1.0.54-sources.jar: com/xdja/poc/sdk/business/RoomStatus.java <==
package com.xdja.poc.sdk.business;

import android.support.annotation.Keep;

/**
 * Created by john on 2018/9/6.
 */

@Keep
public class RoomStatus {
    private volatile boolean isCreated;//是否创建成功
    private volatile boolean isCreating;//是否正在创建
    private volatile boolean isJoined;//是否加入
    private volatile boolean isJoining;//是否正在加入
    private volatile boolean isDestroy;//是否销毁
    private volatile boolean isLeave;//是否离开
    private volatile boolean isForceInsert;//是否强插
    public boolean isAttached() {
        return isAttached;
    }

    public void setAttached(boolean attached) {
        isAttached = attached;
    }

    private volatile boolean isAttached;//是否Attach

    public boolean isCreated() {
        return isCreated;
    }

    public void setCreated(boolean create) {
        isCreated = create;
    }

    public boolean isCreating() {
        return isCreating;
    }

    public void setCreating(boolean creating) {
        isCreating = creating;
    }

    public boolean isJoined() {
        return isJoined;
    }

    public void setJoined(boolean join) {
        isJoined = join;
    }

    public boolean isJoining() {
        return isJoining;
    }

    public void setJoining(boolean joining) {
        isJoining = joining;
    }

    public boolean isDestroy() {
        return isDestroy;
    }

    public void setDestroy(boolean destroy) {
        isDestroy = destroy;
    }

    public boolean isLeave() {
        return isLeave;
    }

    public void setLeave(boolean leave) {
        isLeave = leave;
    }

    public boolean isForceInsert() {
        return isForceInsert;
    }

    public void setForceInsert(boolean forceInsert) {
        isForceInsert = forceInsert;
    }

    public RoomStatus(boolean isCreated, boolean isCreating, boolean isJoining, boolean isJoin, boolean isDestroy, boolean isLeave) {
        this.isCreated = isCreated;
        this.isCreating = isCreating;
        this.isJoined = isJoin;
        this.isJoining = isJoining;
        this.isDestroy = isDestroy;
        this.isLeave = isLeave;
    }


    public RoomStatus() {
    }


    @Override
    public String toString(){
        StringBuffer sb = new StringBuffer();
        sb.append("isCreated:");
        sb.append(isCreated);
        sb.append(",isCreating:");
        sb.append(isCreating);
        sb.append(",isJoined:");
        sb.append(isJoined);
        sb.append(",isJoining:");
        sb.append(isJoining);
        sb.append(",isDestroy:");
        sb.append(isDestroy);
        sb.append(",isLeave:");
        sb.append(isLeave);
        sb.append(",isForceInsert:");
        sb.append(isForceInsert);

        return sb.toString();
    }
}

==> POCSdk-1.0.80-sources.jar: com/xdja/poc/sdk/business/RoomStatus.java <==
package com.xdja.poc.sdk.business;

import android.support.annotation.Keep;

/**
 * Created by john on 2018/9/6.
 */

@Keep
public class RoomStatus {
    private volatile boolean isCreated;//是否创建成功
    private volatile boolean isCreating;//是否正在创建
    private volatile boolean isJoined;//是否加入
    private volatile boolean isJoining;//是否正在加入
    private volatile boolean isDestroy;//是否销毁
    private volatile boolean isLeave;//是否离开
    private volatile boolean isForceInsert;//是否强插
    public boolean isAttached() {
        return isAttached;
    }

    public void setAttached(boolean attached) {
        isAttached = attached;
    }

    private volatile boolean isAttached;//是否Attach

    public boolean isCreated() {
        return isCreated;
    }

    public void setCreated(boolean create) {
        isCreated = create;
    }

    public boolean isCreating() {
        return isCreating;
    }

    public void setCreating(boolean creating) {
        isCreating = creating;
    }

    public boolean isJoined() {
        return isJoined;
    }

    public void setJoined(boolean join) {
        isJoined = join;
    }

    public boolean isJoining() {
        return isJoining;
    }

    public void setJoining(boolean joining) {
        isJoining = joining;
    }

    public boolean isDestroy() {
        return isDestroy;
    }

    public void setDestroy(boolean destroy) {
        isDestroy = destroy;
    }

    public boolean isLeave() {
        return isLeave;
    }

    public void setLeave(boolean leave) {
        isLeave = leave;
    }

    public boolean isForceInsert() {
        return isForceInsert;
    }

    public void setForceInsert(boolean forceInsert) {
        isForceInsert = forceInsert;
    }

    public RoomStatus(boolean isCreated, boolean isCreating, boolean isJoining, boolean isJoin, boolean isDestroy, boolean isLeave) {
        this.isCreated = isCreated;
        this.isCreating = isCreating;
        this.isJoined = isJoin;
        this.isJoining = isJoining;
        this.isDestroy = isDestroy;
        this.isLeave = isLeave;
    }


    public RoomStatus() {
    }


    @Override
    public String toString(){
        String sb = "isCreated:" +
                isCreated +
                ",isCreating:" +
                isCreating +
                ",isJoined:" +
                isJoined +
                ",isJoining:" +
                isJoining +
                ",isDestroy:" +
                isDestroy +
                ",isLeave:" +
                isLeave +
                ",isForceInsert:" +
                isForceInsert;

        return sb;
    }
}
